FlowFieldTilesBundle

Struct FlowFieldTilesBundle 

pub struct FlowFieldTilesBundle {
    pub sector_cost_fields: SectorCostFields,
    pub sector_portals: SectorPortals,
    pub portal_graph: PortalGraph,
    pub map_dimensions: MapDimensions,
    pub route_cache: RouteCache,
    pub flow_field_cache: FlowFieldCache,
}
Defines all required components for generating FlowField Tiles

Fields

sector_cost_fields: SectorCostFields

CostFields of all sectors

sector_portals: SectorPortals

Portals for all sectors

portal_graph: PortalGraph

Graph describing how to get from one sector to another

map_dimensions: MapDimensions

Size of the world

route_cache: RouteCache

Cache of overarching portal-portal routes

flow_field_cache: FlowFieldCache

Cache of FlowFields that can be queried in a steering pipeline

Implementations

Source

impl FlowFieldTilesBundle

pub fn get_sector_cost_fields(&self) -> &SectorCostFields

Get a reference to the SectorCostFields

pub fn get_sector_portals(&self) -> &SectorPortals

Get a reference to the SectorPortals

pub fn get_portal_graph(&self) -> &PortalGraph

Get a reference to the PortalGraph

pub fn get_map_dimensions(&self) -> &MapDimensions

Get a reference to the MapDimensions

pub fn get_route_cache(&self) -> &RouteCache

Get a reference to the RouteCache

pub fn get_route_cache_mut(&mut self) -> &mut RouteCache

Get a mutable reference to the RouteCache

pub fn get_flowfield_cache(&self) -> &FlowFieldCache

Get a reference to the FlowFieldCache

pub fn get_flowfield_cache_mut(&mut self) -> &mut FlowFieldCache

Get a mutable reference to the FlowFieldCache

pub fn new( map_length: u32, map_depth: u32, sector_resolution: u32, actor_size: f32, ) -> Self

Create a new instance of FlowFieldTilesBundle based on map dimensions

pub fn from_ron( map_length: u32, map_depth: u32, sector_resolution: u32, actor_size: f32, path: &str, ) -> Self

Create a new instance of FlowFieldTilesBundle based on map dimensions where the SectorCostFields are derived from a .ron file

pub fn from_csv( map_length: u32, map_depth: u32, sector_resolution: u32, actor_size: f32, directory: &str, ) -> Self

Create a new instance of FlowFieldTilesBundle from a directory containing CSV CostField files

pub fn from_heightmap( map_length: u32, map_depth: u32, sector_resolution: u32, actor_size: f32, file_path: &str, ) -> Self

From a greyscale heightmap image initialise a bundle where the CostFields are derived from the pixel values of the image

pub fn from_bevy_2d_meshes( meshes: Vec<(&Mesh, Vec2)>, map_length: u32, map_depth: u32, sector_resolution: u32, actor_size: f32, internal_cost: u8, external_cost: u8, ) -> Self

From a list of 2d meshes and their translation initialise a bundle. The vertex points of the meshes must be within the map_length and map_depth of the world.

The default cell Costs can be set with internal_cost and external_cost for cells within any meshs and for cells outside of any meshes