IntegrationField

Struct IntegrationField 

pub struct IntegrationField { /* private fields */ }

Implementations

Source

impl IntegrationField

pub fn new(goal: &FieldCell, cost: &CostField) -> Self

Creates a new IntegrationField where all cells are set to u16::MAX and impassable cells are set to include a bit flag and while the goal is set to 0

pub fn set_initial_los(&mut self, cell_id: FieldCell)

Sets the goal (not any portals) of the target sector as having Line Of Sight

pub fn add_los_corner(&mut self, corner: FieldCell)

Append a new Line Of Sight corner to the integration field

pub fn calculate_sector_goal_los( &mut self, active_wavefront: &[FieldCell], goal: &FieldCell, )

From the goal of the target sector calcualte LOS

pub fn calculate_field(&mut self, cost_field: &CostField)

From a list of Corners field cells iterate over successive neighbouring cells and calculate the integrated-cost field values from the cost_field