pub struct IntegrationField { /* private fields */ }Implementations
Sourceimpl IntegrationField
impl IntegrationField
Sourcepub fn new(goal: &FieldCell, cost: &CostField) -> Self
pub fn new(goal: &FieldCell, cost: &CostField) -> Self
Creates a new IntegrationField where all cells are set to u16::MAX
and impassable cells are set to include a bit flag and while the goal
is set to 0
Sourcepub fn set_initial_los(&mut self, cell_id: FieldCell)
pub fn set_initial_los(&mut self, cell_id: FieldCell)
Sets the goal (not any portals) of the target sector as having Line Of Sight
Sourcepub fn add_los_corner(&mut self, corner: FieldCell)
pub fn add_los_corner(&mut self, corner: FieldCell)
Append a new Line Of Sight corner to the integration field
Sourcepub fn calculate_sector_goal_los(
&mut self,
active_wavefront: &[FieldCell],
goal: &FieldCell,
)
pub fn calculate_sector_goal_los( &mut self, active_wavefront: &[FieldCell], goal: &FieldCell, )
From the goal of the target sector calcualte LOS
Sourcepub fn calculate_field(&mut self, cost_field: &CostField)
pub fn calculate_field(&mut self, cost_field: &CostField)
From a list of Corners field cells iterate over successive neighbouring
cells and calculate the integrated-cost field values from the
cost_field